@@ -1,7 +1,7 @@
 package Bot::ChatBots::Telegram::Role::Source;
 use strict;
 use warnings;
-{ our $VERSION = '0.011'; }
+{ our $VERSION = '0.011001'; }
 
 use Ouch;
 use Log::Any;
@@ -15,6 +15,16 @@ has token => (
    default => sub { ouch 500, 'token is not defined' }
 );
 
+has sender => (
+   is      => 'ro',
+   lazy    => 1,
+   default => sub {    # prefer has-a in this case
+      my $self = shift;
+      require Bot::ChatBots::Telegram::Sender;
+      return Bot::ChatBots::Telegram::Sender->new(token => $self->token);
+   },
+);
+
 {
    my %data_type_for = (
       message => 'Message',
